# Dynatrace Extensions Python SDK

[![PyPI - Version](https://img.shields.io/pypi/v/dt-extensions-sdk.svg)](https://pypi.org/project/dt-extensions-sdk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dt-extensions-sdk.svg)](https://pypi.org/project/dt-extensions-sdk)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [Developing](#developing)

## Installation

```console
pip install dt-extensions-sdk
```

## License

`dt-extensions-sdk` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Developing

### Testing

```console
hatch run test
```

### Linting

```console
hatch run lint:all
```

### Building

```console
hatch build
```